#!/usr/bin/perl

use warnings;
use strict;

my $debug = 0;
my $domain_nc = `/opt/novell/xad/share/dcinit/printConfigKey.pl 'Domain NC'`;
chomp($domain_nc);

my @ldap_output=`LDAPCONF=/etc/opt/novell/xad/openldap/ldap.conf ldapsearch -Q -Y EXTERNAL -s sub -b $domain_nc 'objectclass=msds:computer' dn -LLL -o ldif-wrap=no`;

if ($? != 0) {
	my $err = $? >> 8;
	chomp(@ldap_output);
	print "Failed to search the computer objects : $err : [@ldap_output]\n";
	exit -1;
}

chomp(@ldap_output);

my @all_computers = grep (!/ou=domain controllers,/ig, @ldap_output);
@all_computers = grep (/^dn:/ig, @all_computers);

my $ldif_file = "/var/opt/novell/xad/ds/domain/update_computer_acls.ldif";
open LDIFFILE,">$ldif_file" 
		 or die('Could not open the ldif file \n');

foreach my $computer (@all_computers) {
	print "Updating acls on computer [$computer]\n" if ($debug);

	my $computer_cn = $computer;
	$computer_cn =~ s/^dn: //i;

	print LDIFFILE "$computer\n";
	print LDIFFILE "changeType: modify\n";
	print LDIFFILE "add: ACL\n";
	print LDIFFILE "ACL: 6#entry#$computer_cn#operatingSystem\n";
	print LDIFFILE "ACL: 6#entry#$computer_cn#operatingSystemVersion\n";
	print LDIFFILE "ACL: 6#entry#$computer_cn#operatingSystemServicePack\n\n";
}
close LDIFFILE;


print "Updating the ACLs on the computer objects \n" if ($debug);

my @output = `LDAPCONF=/etc/opt/novell/xad/openldap/ldap.conf ldapmodify -Q -c\\
			-Y EXTERNAL -f $ldif_file 2>&1`;
my $err = $? >> 8;
if ($? != 0 and $err != 20) {
	chomp (@output);
	print "Failed to update ACLs on computer object : $err: [@output]\n";
	exit -1;
}
else {
	print "Successfully updated the ACLs on the computer objects \n";
}

